@@ -1,5 +1,5 @@
 char copyright[]=
-"xbmbrowser Version 4.0 (c) Copyright Ashley Roll and Anthony Thyssen.";
+"xbmbrowser Version 5.0 (c) Copyright Ashley Roll and Anthony Thyssen.";
 /*
 *****************************************************************************
 ** FILE: xbmbrowser.c
@@ -36,10 +36,20 @@ char copyright[]=
 #include "filesyms/file.xbm"
 #include "filesyms/text.xbm"
 #include "filesyms/binary.xbm"
-#include "filesyms/xbm.xbm"  /* Xbm and xpm do not really need these symbols */
-#include "filesyms/xpm.xbm"  /* but are included for completeness */
+#include "filesyms/xbm.xbm"  /* Xbm and Xpm do not really need these symbols */
+#include "filesyms/xpm.xbm"  /* but are included for completeness, who knows!*/
 #include "filesyms/xpmbad.xbm"
 
+/* mask bitmaps for file symbols */
+#include "filesyms/dirmask.xbm"
+#include "filesyms/filemask.xbm"
+
+/* Define the width to give the main buttons.
+** This width is reduced by the form widget to fit the
+** applications real width, but sound be the same for all
+** the buttons defined in the button box. */
+#define  BUTTON_WIDTH 100
+
 /* -------------------------- */
 static Atom  wm_delete_window;      /* insure that delete window works */
 
@@ -59,57 +69,80 @@ static XrmOptionDescRec cmdline_options[] = {
   {"-nodir",       "*show_dir",     XrmoptionNoArg,  "False"},
   {"-noxpmbad",    "*show_xpmbad",  XrmoptionNoArg,  "False"},
   {"-noother",     "*show_other",   XrmoptionNoArg,  "False"},
+  /* special resources toggles */
+  {"-solid",       "*solid_bgnd",   XrmoptionNoArg,  "True"},
+  {"-stipple",     "*solid_bgnd",   XrmoptionNoArg,  "False"},
+  {"-label",       "*label_all",    XrmoptionNoArg,  "True"},
+  {"-nolabel",     "*label_all",    XrmoptionNoArg,  "False"},
   /* recursive directory scan */
   {"-R",           "*recursive",    XrmoptionNoArg,  "True"},
   {"-recursive",   "*recursive",    XrmoptionNoArg,  "True"},
 };
 
+/* Unknown is a boolean! value which means it was never set
+** by any user resource. Used to calculate a correct default
+** later in the main initialization section. */
+#define Bool_Unset (Boolean)2
+
 /* define the applications own resources */
+#define offset(field)  XtOffsetOf(AppData, field)
 static XtResource resources[] = {
-  /* res_name    res_class    res_type
-   *   var_size    var_ptr  
-   *     var_type     default_value */
-  /* configuration resources */
-  { "cmd_rc",       "Config",   XtRString,
-       sizeof(char *),  XtOffset(AppDataPtr, cmd_rc),
-         XtRString,        (XtPointer) NULL },
-  { "user_rc",      "Config",   XtRString,
-       sizeof(char *),   XtOffset(AppDataPtr, user_rc),
-         XtRString,        (XtPointer) USERS_RC },
-  { "library_rc",   "Config",   XtRString,
-       sizeof(char *),   XtOffset(AppDataPtr, library_rc),
-         XtRString,        (XtPointer) LIBRARY_RC },
-  /* symbol resources */
-  { "icons_only",   "Show",     XtRBoolean,
-       sizeof(Boolean), XtOffset(AppDataPtr, icons_only),
-         XtRImmediate,     (XtPointer) False },
-  { "show_dir",     "Show",     XtRBoolean,
-       sizeof(Boolean), XtOffset(AppDataPtr, show_dir),
-         XtRImmediate,     (XtPointer) True },
-  { "show_xpmbad",  "Show",     XtRBoolean,
-       sizeof(Boolean), XtOffset(AppDataPtr, show_xpmbad),
-         XtRImmediate,     (XtPointer) True },
-  { "show_other",   "Show",     XtRBoolean,
-       sizeof(Boolean), XtOffset(AppDataPtr, show_other),
-         XtRImmediate,     (XtPointer) False },
-  /* recursive directory scan */
-  { "recursive",   XtCBoolean,  XtRBoolean,
-       sizeof(Boolean), XtOffset(AppDataPtr, recursive),
-         XtRImmediate,     (XtPointer) False },
-  /* colors for symbols and bitmap icons */
-  { "sym_foreground",  XtCForeground,  XtRPixel,
-       sizeof(Pixel), XtOffset(AppDataPtr, sym_fore),
-         XtRString,     (XtPointer) XtDefaultForeground },
-  { "sym_background",  XtCBackground,  XtRPixel,
-       sizeof(Pixel), XtOffset(AppDataPtr, sym_back),
-         XtRString,     (XtPointer) XtDefaultBackground },
-  { "icon_foreground",  XtCForeground,  XtRPixel,
-       sizeof(Pixel), XtOffset(AppDataPtr, icon_fore),
-         XtRString,     (XtPointer) XtDefaultForeground },
-  { "icon_background",  XtCBackground,  XtRPixel,
-       sizeof(Pixel), XtOffset(AppDataPtr, icon_back),
-         XtRString,     (XtPointer) XtDefaultBackground },
+  /* res_name  res_class  res_type  var_size 
+   *   var_ptr   var_type   default_value   */
+/* --- configuration resources --- */
+  { "cmd_rc",       "Config",   XtRString, sizeof(char *),
+       offset(cmd_rc), XtRString, (XtPointer) NULL },
+  { "user_rc",      "Config",   XtRString, sizeof(char *),
+       offset(user_rc), XtRString, (XtPointer) USERS_RC },
+  { "library_rc",   "Config",   XtRString, sizeof(char *),
+       offset(library_rc), XtRString, (XtPointer) LIBRARY_RC },
+/* --- option menu resources --- */
+  /* display style resources */
+  { "solid_bgnd",   XtCBoolean,  XtRBoolean, sizeof(Boolean),
+       offset(solid_bgnd), XtRImmediate,  (XtPointer) Bool_Unset },
+  { "shape_syms",   XtCBoolean,  XtRBoolean, sizeof(Boolean),
+       offset(shape_syms), XtRImmediate,  (XtPointer) Bool_Unset },
+  { "label_all",   XtCBoolean,  XtRBoolean, sizeof(Boolean),
+       offset(label_all), XtRImmediate,   (XtPointer) False },
+  { "label_icons",   XtCBoolean,  XtRBoolean, sizeof(Boolean),
+       offset(label_icons), XtRImmediate, (XtPointer) False },
+  { "label_syms",   XtCBoolean,  XtRBoolean, sizeof(Boolean),
+       offset(label_syms), XtRImmediate,  (XtPointer) False },
+  { "label_dirs",   XtCBoolean,  XtRBoolean, sizeof(Boolean),
+       offset(label_dirs), XtRImmediate,  (XtPointer) False },
+  /* visibility resources */
+  { "icons_only",   "Show",     XtRBoolean, sizeof(Boolean),
+       offset(icons_only), XtRImmediate,  (XtPointer) False },
+  { "show_dir",     "Show",     XtRBoolean, sizeof(Boolean),
+       offset(show_dir), XtRImmediate,    (XtPointer) True },
+  { "show_xpmbad",  "Show",     XtRBoolean, sizeof(Boolean),
+       offset(show_xpmbad), XtRImmediate, (XtPointer) True },
+  { "show_other",   "Show",     XtRBoolean, sizeof(Boolean),
+       offset(show_other), XtRImmediate,  (XtPointer) False },
+  { "show_hidden",  "Show",     XtRBoolean, sizeof(Boolean),
+       offset(show_hidden), XtRImmediate, (XtPointer) False },
+  /* recursive scan resource */
+  { "recursive",   XtCBoolean,  XtRBoolean, sizeof(Boolean),
+       offset(recursive), XtRImmediate,   (XtPointer) False },
+/* --- Colors --- */
+  /* symbols and bitmap icon colors */
+  { "sym_foreground",  XtCForeground,  XtRPixel, sizeof(Pixel),
+       offset(sym_fg), XtRString, (XtPointer) XtDefaultForeground },
+  { "sym_background",  XtCBackground,  XtRPixel, sizeof(Pixel),
+       offset(sym_bg), XtRString, (XtPointer) XtDefaultBackground },
+  { "icon_foreground",  XtCForeground,  XtRPixel, sizeof(Pixel),
+       offset(icon_fg), XtRString, (XtPointer) XtDefaultForeground },
+  { "icon_background",  XtCBackground,  XtRPixel, sizeof(Pixel),
+       offset(icon_bg), XtRString, (XtPointer) XtDefaultBackground },
+  /* background colors */
+  { "icon_transparent",  XtCBackground,  XtRPixel, sizeof(Pixel),
+       offset(icon_tr), XtRString, (XtPointer) XtDefaultBackground },
+  { "solid_background",  XtCBackground,  XtRPixel, sizeof(Pixel),
+       offset(solid_bg), XtRString, (XtPointer) XtDefaultBackground },
+  { "stipple_background",  XtCBackground,  XtRPixel, sizeof(Pixel),
+       offset(stipple_bg), XtRString, (XtPointer) XtDefaultBackground },
 };
+#undef offset
 
 /* declare action routines for translations */
 static XtActionsRec  actions[] = {
@@ -122,34 +155,48 @@ static XtActionsRec  actions[] = {
   { "Quit",       quit_browser },    /* quit application */
 };
 
-/* translation table for label widgets for the bitmaps */
-char Translations[] = 
+/* translation table (override) for menu (command) widget */
+static char menu_trans[] =
+  "<EnterWindow>:  highlight() \n\
+   <LeaveWindow>:  reset() \n\
+   <BtnDown>:      Pop_Menu() \n\
+   <BtnDown>(2+): ";  /* this stops double clicks crashing the program */
+
+/* translation table for widget displaying the icon images */
+char icon_trans[] = 
   "<EnterWindow>:  Set_Name() \n\
    <LeaveWindow>:  Set_Label() \n\
-   <BtnDown>:      Pop_Menu() ";
+   <BtnDown>:      Pop_Menu() \n\
+   <BtnDown>(2+): ";  /* this stops double clicks crashing the program */
 
-/* translation table for the dialogWidget (directory name) */
+/* translation table (override) for "global" popup anywhere in the iconbox */
+static char box_trans[] =
+  "<BtnDown>:      Pop_Menu() \n\
+   <BtnDown>(2+): ";  /* this stops double clicks crashing the program */
+
+/* translation table (override) for the directory text widget */
 static char text_trans[] = 
   "<Key>Return:  Dir_Return() \n\
    Ctrl<Key>M:   Dir_Return() \n\
    <Btn3Down>:   Pos_Dir() MenuPopup(dirmenu) ";
 
-/*  translation table for the list widget */
+/* translation table for the directory list popup menu */
 static char list_trans[] =
    "<Enter>:      Set() \n\
     <Leave>:      Unset() \n\
     <BtnMotion>:  Set() \n\
     <BtnUp>:      MenuPopdown(dirmenu) Notify() Unset()"; 
 
-/*  translation table for the transient shell containing the list */
-/* this translation makes the list popdown if the button is released 
-   outside the window */
+/* translation table for the transient shell containing the list
+** This translation makes the list popdown if the button is released 
+** outside the window    -- Ashley Roll */
 static char tshell_trans[] = 
        "<BtnUp>: MenuPopdown(dirmenu)";
 
+
 /* fallback resources -- things required to function at all */
 static char *fall_back[] = {
-   "XbmBrowser.width:    450",
+   "XbmBrowser.width:    500",
    "XbmBrowser.height:   600",
    "*optmenu*leftMargin: 24", 
    NULL
@@ -159,15 +206,18 @@ static char *fall_back[] = {
 
 static void usage()
 {
-  fprintf(stderr, "%s%s%s%s%s%s%s%s%s",
+  fprintf(stderr, "%s%s%s%s%s%s%s%s%s%s%s%s",
     "Usage: xbmbrowser [options...] [directory]\n",
     "    Where ``directory'' is an directory of icons to display.\n",
     "    Options can be any standard X toolkit option or...\n",
     "       -config file     Use the given config file instead\n",
+    "       -solid           Use a solid background and shaped windows\n",
+    "       -stipple         Stripple background and unshaped icons\n",
     "       -(no)iconsonly   (Don't) Display only the icon images\n",
     "       -(no)dir         (Don't) Display directories found\n",
     "       -(no)xpmbad      (Don't) Display Bad X Pixmap Loads\n",
     "       -(no)other       (Don't) Display other files\n",
+    "       -(no)label       (Don't) Label the displayed icon images\n",
     "       -R | -recursive  Recursive Scan of all sub-directories\n"
   );
   exit(1);
@@ -202,14 +252,24 @@ main(argc, argv)
     XtAppAddActions( appcon, actions, XtNumber(actions) );
   }
 
+  /* collect some extra information */
+  display  = XtDisplay(toplevel);
+  screen   = XtScreen(toplevel);
+  colormap = DefaultColormapOfScreen(screen);
+  depth    = DefaultDepthOfScreen(screen);
+
+#if 0
+  /* Color Tests of the display -- Pixmap Debugging */
+  printf("icon: fore=%d, back=%d, trans=%d\n",
+     app_data.icon_fore, app_data.icon_back, app_data.icon_trans );
+#endif
+
   /* If no icon is set by the user -- set a default one */
   { Pixmap icon;
 
     XtVaGetValues(toplevel, XtNiconPixmap, &icon, NULL);
     if ( icon == None ) {
-      icon = XCreateBitmapFromData(
-              XtDisplay(toplevel), RootWindowOfScreen(XtScreen(toplevel)),
-              (char *)icon_bits, icon_width, icon_height);
+      icon = LOAD_BMAP(icon);
       XtVaSetValues(toplevel, XtNiconPixmap, icon, NULL);
     }
   }
@@ -291,8 +351,8 @@ main(argc, argv)
   }
 
   /* CD and Initialize dir_name correctly
-  ** DO NOT call change_dir() later as this withh reset
-  ** resursive resource setting
+  ** DO NOT call change_dir() now as this will reset the current
+  ** resursive resource setting given by the user on the command line.
   */
   if( dir_name[0] != '\0' && chdir(dir_name) != 0 ) {
     fprintf(stderr,"xbmbrowser: couldn't chdir to '%s'\n",argv[1]);
@@ -302,36 +362,39 @@ main(argc, argv)
   if( strcmp(dir_name,"/") != 0 )
     (void) strncat(dir_name, "/", MAXNAMLEN);
 
-  /* collect some extra information */
-  display  = XtDisplay(toplevel);
-  colormap = DefaultColormapOfScreen(XtScreen(toplevel));
+  /* copy this as the initial startup directory */
+  strcpy(init_dir, dir_name);
 
   /* create the cursors */
   normalCursor = XCreateFontCursor(display, XC_left_ptr);
   waitCursor   = XCreateFontCursor(display, XC_watch);
 
+  /* NOTE: LOAD_BMAP(file) is a marco to creat a X bitmap from bitmap data */
+
   /* create tickbox bitmaps for options menu */
-  tickoff = XCreateBitmapFromData(
-              XtDisplay(toplevel), RootWindowOfScreen(XtScreen(toplevel)),
-              (char *)tickbox_off_bits, tickbox_off_width, tickbox_off_height);
-  tickon  = XCreateBitmapFromData(
-              XtDisplay(toplevel), RootWindowOfScreen(XtScreen(toplevel)),
-              (char *)tickbox_on_bits, tickbox_on_width, tickbox_on_height);
+  tickoff = LOAD_BMAP(tickbox_off);
+  tickon  = LOAD_BMAP(tickbox_on);
+
+  /* load masks first and save them */
+  sym_masks[Dir] = sym_masks[DirUp] = sym_masks[DirLink] =
+     sym_masks[DirBad] = LOAD_BMAP(dirmask);
+  sym_masks[File] = sym_masks[Text] = sym_masks[Binary] =
+     sym_masks[Xbm] = sym_masks[Xpm] = sym_masks[XpmBad] =
+     sym_masks[Unknown] = LOAD_BMAP(filemask);
+
+  /* Load and save the rest of the file symbols */
+  sym_bmaps[Unknown] = LOAD_BMAP(unknown);
+  sym_bmaps[Dir]     = LOAD_BMAP(dir);
+  sym_bmaps[DirUp]   = LOAD_BMAP(dirup);
+  sym_bmaps[DirLink] = LOAD_BMAP(dirlink);
+  sym_bmaps[DirBad]  = LOAD_BMAP(dirbad);
+  sym_bmaps[File]    = LOAD_BMAP(file);
+  sym_bmaps[Text]    = LOAD_BMAP(text);
+  sym_bmaps[Binary]  = LOAD_BMAP(binary);
+  sym_bmaps[Xbm]     = LOAD_BMAP(xbm);
+  sym_bmaps[Xpm]     = LOAD_BMAP(xpm);
+  sym_bmaps[XpmBad]  = LOAD_BMAP(xpmbad);
 
-  /* load all the filetype symbols require.
-  ** LOAD_SYM(sym, file) is a macro.
-  */
-  LOAD_SYM(Unknown, unknown);
-  LOAD_SYM(Dir,     dir);
-  LOAD_SYM(DirUp,   dirup);
-  LOAD_SYM(DirLink, dirlink);
-  LOAD_SYM(DirBad,  dirbad);
-  LOAD_SYM(File,    file);
-  LOAD_SYM(Text,    text);
-  LOAD_SYM(Binary,  binary);
-  LOAD_SYM(Xbm,     xbm);
-  LOAD_SYM(Xpm,     xpm);
-  LOAD_SYM(XpmBad,  xpmbad);
 
   /* create a paned widget to put everything into */
   mainpw  = XtVaCreateManagedWidget(
@@ -340,7 +403,7 @@ main(argc, argv)
               NULL);
 
   /* create buttons and options menu */
-  { Widget form, button, option, optmenu, optitem;
+  { Widget form, button, options, optmenu, optitem;
 
     /* create form to hold the buttons */
     form = XtVaCreateManagedWidget(
@@ -349,31 +412,70 @@ main(argc, argv)
               XtNskipAdjust, (XtArgVal)True,NULL);
 
     /* create the Buttons */
-    button = XtVaCreateManagedWidget(
-              "quit", commandWidgetClass, form,
+    mainmenu = XtVaCreateManagedWidget(
+              "mainmenu", commandWidgetClass, form,
+              XtNwidth,      (XtArgVal)BUTTON_WIDTH,
               NULL);
-    XtAddCallback(button, XtNcallback, quit_browser, NULL);
-    option = XtVaCreateManagedWidget(
+    XtOverrideTranslations(mainmenu, XtParseTranslationTable(menu_trans));
+    options = XtVaCreateManagedWidget(
               "options", menuButtonWidgetClass, form,
-              XtNfromHoriz,  (XtArgVal)button,
+              XtNwidth,      (XtArgVal)BUTTON_WIDTH,
+              XtNfromHoriz,  (XtArgVal)mainmenu,
               XtNmenuName,   (XtArgVal)"optmenu",
               NULL);
     button = XtVaCreateManagedWidget(
               "rescan", commandWidgetClass, form,
-              XtNfromHoriz,  (XtArgVal)option,
+              XtNwidth,      (XtArgVal)BUTTON_WIDTH,
+              XtNfromHoriz,  (XtArgVal)options,
               NULL);
     XtAddCallback(button, XtNcallback, rescan, NULL);
 
     button = XtVaCreateManagedWidget(
               "scan", commandWidgetClass, form,
+              XtNwidth,      (XtArgVal)BUTTON_WIDTH,
               XtNfromHoriz,  (XtArgVal)button,
               NULL);
     XtAddCallback(button, XtNcallback, scan, NULL);
 
+    /* initialize the solid_bgnd resource is still unset */
+    if ( app_data.solid_bgnd == Bool_Unset )
+      app_data.solid_bgnd = (depth > 1);   /* true if on color display */
+
+    if ( app_data.shape_syms == Bool_Unset )
+      app_data.shape_syms = app_data.solid_bgnd;  /* true if on color display */
+
     /* create the options menu */
     optmenu = XtVaCreatePopupShell(
-              "optmenu", simpleMenuWidgetClass, option,
+              "optmenu", simpleMenuWidgetClass, options,
               NULL);
+    /* ----- display style options ----- */
+    optitem = XtVaCreateManagedWidget(
+              "solid_bgnd", smeBSBObjectClass, optmenu,
+              XtNleftBitmap, app_data.solid_bgnd ? tickon : tickoff, NULL);
+    XtAddCallback(optitem, XtNcallback, toggle_option, &app_data.solid_bgnd);
+    optitem = XtVaCreateManagedWidget(
+              "shape_syms", smeBSBObjectClass, optmenu,
+              XtNleftBitmap, app_data.shape_syms ? tickon : tickoff, NULL);
+    XtAddCallback(optitem, XtNcallback, toggle_option, &app_data.shape_syms);
+    optitem = XtVaCreateManagedWidget(
+              "label_all", smeBSBObjectClass, optmenu,
+              XtNleftBitmap, app_data.label_all ? tickon : tickoff, NULL);
+    XtAddCallback(optitem, XtNcallback, toggle_option, &app_data.label_all);
+    optitem = XtVaCreateManagedWidget(
+              "label_icons", smeBSBObjectClass, optmenu,
+              XtNleftBitmap, app_data.label_icons ? tickon : tickoff, NULL);
+    XtAddCallback(optitem, XtNcallback, toggle_option, &app_data.label_icons);
+    optitem = XtVaCreateManagedWidget(
+              "label_syms", smeBSBObjectClass, optmenu,
+              XtNleftBitmap, app_data.label_syms ? tickon : tickoff, NULL);
+    XtAddCallback(optitem, XtNcallback, toggle_option, &app_data.label_syms);
+    optitem = XtVaCreateManagedWidget(
+              "label_dirs", smeBSBObjectClass, optmenu,
+              XtNleftBitmap, app_data.label_dirs ? tickon : tickoff, NULL);
+    XtAddCallback(optitem, XtNcallback, toggle_option, &app_data.label_dirs);
+
+    /* ----- what is visible options ----- */
+    XtVaCreateManagedWidget("line", smeLineObjectClass, optmenu, NULL);
     optitem = XtVaCreateManagedWidget(
               "icons_only", smeBSBObjectClass, optmenu,
               XtNleftBitmap, app_data.icons_only ? tickon : tickoff, NULL);
@@ -391,14 +493,20 @@ main(argc, argv)
               XtNleftBitmap, app_data.show_other ? tickon : tickoff, NULL);
     XtAddCallback(optitem, XtNcallback, toggle_option, &app_data.show_other);
     optitem = XtVaCreateManagedWidget(
-              "line", smeLineObjectClass, optmenu, NULL);
+              "show_hidden", smeBSBObjectClass, optmenu,
+              XtNleftBitmap, app_data.show_hidden ? tickon : tickoff, NULL);
+    XtAddCallback(optitem, XtNcallback, toggle_option, &app_data.show_hidden);
+
+    /* ----- recursive scaning of directories ----- */
     /* this is globally known so change_dir() can reset it */
+    XtVaCreateManagedWidget("line", smeLineObjectClass, optmenu, NULL);
     recur_opt = XtVaCreateManagedWidget(
               "recursive", smeBSBObjectClass, optmenu,
               XtNleftBitmap, app_data.recursive ? tickon : tickoff, NULL);
     XtAddCallback(recur_opt, XtNcallback, toggle_option, &app_data.recursive);
   }
 
+
   /* dialogWidget -- show and change the current directory
   ** NOTE: the actual value for this widget set in change_dir() 
   */
@@ -435,14 +543,14 @@ main(argc, argv)
               XtNshowGrip,   (XtArgVal)False,
               XtNskipAdjust, (XtArgVal)True,NULL);
 
-  /* setup the box to hold all the bitmaps */
+
+  /* setup the box to hold all the images */
   { Widget  viewport;
-    Pixmap  stipple;
-    int     width, fore, back, depth;
+    int     width;
 
     XtVaGetValues(toplevel,XtNwidth,&width,NULL);
  
-    /* create a viewport widget to stick the bitmaps in */
+    /* create a viewport widget to stick the images in */
     viewport = XtVaCreateManagedWidget(
               "viewport",viewportWidgetClass,mainpw,
               XtNwidth,(XtArgVal)width,
@@ -451,24 +559,24 @@ main(argc, argv)
               XtNshowGrip,(XtArgVal)False,
               XtNskipAdjust,(XtArgVal)True,NULL);
 
-    /* create the box widget to put all the bitmaps in */
-    bitmaps = XtVaCreateManagedWidget(
-              "bitmaps",      boxWidgetClass,  viewport,
+    /* create the box widget to put all the icon images in */
+    iconbox = XtVaCreateManagedWidget(
+              "iconbox",      boxWidgetClass,  viewport,
               XtNwidth,       width,
               XtNorientation, (XtArgVal)XtorientVertical,
               XtNfromVert,    (XtArgVal)label,
               NULL);
-
-    /* find and set the stipple background pattern */
-    XtVaGetValues(bitmaps,
-              XtNborderColor, &fore,
-              XtNbackground,  &back,
-              XtNdepth,       &depth, NULL);
-    stipple = XmuCreateStippledPixmap(XtScreen(bitmaps), fore, back, depth);
-    XtVaSetValues(bitmaps,
-              XtNbackgroundPixmap, (XtArgVal)stipple, NULL);
+    /* This is currently NOT working -- It stops the file popups!
+    ** All I want is for the global menu to popup on mouse press anywhere
+    ** in the iconbox, but for the normal actions to continue to work
+    ** when mouse button is used on a displays icon or symbol.
+    ** This overrides everything inside the iconbox. Arrgghhh. */
+    XtOverrideTranslations(iconbox, XtParseTranslationTable(box_trans));
   }
 
+  /* initialize and set the stipple for the icon box */
+  init_stipple(); 
+
   /* WARNING :- Heavy Magic in progress, Xperts please note....
   **   We need to Register the appropiate Grab Information for the
   ** popup_user_menu action routine. This is only needed as we are
@@ -483,8 +591,8 @@ main(argc, argv)
               ButtonPressMask | ButtonReleaseMask,
               GrabModeAsync, GrabModeAsync);
 
-  /* scan for the bitmaps -- DON'T call change_dir() */
-  scan_bitmaps();
+  /* scan for the images -- DON'T call change_dir() */
+  scan_images();
 
   XtRealizeWidget(toplevel);
 
